import { InjectionToken } from '@angular/core';
/**
 * Defines the posible values of the components' display density.
 */
export declare const enum DisplayDensity {
    comfortable = "comfortable",
    cosy = "cosy",
    compact = "compact",
}
/**
 * Describes the object used to configure the DisplayDensity in Angular DI.
 */
export interface IDisplayDensity {
    displayDensity: DisplayDensity;
}
/**
 * Defines the DisplayDensity DI token.
 */
export declare const DisplayDensityToken: InjectionToken<IDisplayDensity>;
/**
 * Base class containing all logic required for implementing DisplayDensity.
 */
export declare class DisplayDensityBase {
    protected displayDensityOptions: IDisplayDensity;
    protected _displayDensity: DisplayDensity | string;
    /**
     * Returns the theme of the component.
     * The default theme is `comfortable`.
     * Available options are `comfortable`, `cosy`, `compact`.
     * ```typescript
     * let componentTheme = this.component.displayDensity;
     * ```
     */
    /**
     * Sets the theme of the component.
     */
    displayDensity: DisplayDensity | string;
    /**
     *@hidden
     */
    protected isCosy(): boolean;
    /**
     *@hidden
     */
    protected isComfortable(): boolean;
    /**
     *@hidden
     */
    protected isCompact(): boolean;
    constructor(displayDensityOptions: IDisplayDensity);
}
